import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';

//This is Iris data set 
const csvUrl =
  'https://gist.githubusercontent.com/vagdevi-369/9d9025feabac5da02e6d7c1c0b6c6a74/raw/80dc20d1fca6504c5996481f3d3f292cd802111a/scatter%2520plot';
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const xValue = (d) => d.petal_length;
const yValue = (d) => d.petal_width;
const rxValue = (d) => d.sepal_length;
const ryValue = (d) => d.sepal_width;
const speciesValue = (d) => d.species;
const colorValue = d => d.species;
const colorLabel = ' 3 Species';


const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.petal_width);
  const y = yValue((d) => d.sepal_length);
  const marker = (d) => {
        	switch(d){
            case 'Iris-setosa': //naming the labels 
              return 'blue';  // adding colors to each lable
            case 'Iris-versicolor':
              return 'LightSkyBlue';
            default:
              return 'red';
          }
        }
  //x and y axis values
  const marks = data.map((d) => ({
          x: xValue((d) => d.petal_width),
          y: yValue((d) => d.sepal_length),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  
//scatterplot arrangement is shown here
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 28,
      right: 53,
      bottom: 82,
      left: 88,

    })
    .radius(5);
  
  
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);





//scattered data structure
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));

     
    
  
  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];

  
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);  
		svg.selectAll('text').remove();
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -70)
          .attr('y', -210)
          .style("font-style","italic")
          .style("stroke","BlueViolet")
          .text(colorLabel);

   
// title format
svg.append("text").attr("x", 450).attr("y", 20).text("Reusable Scatterplot").style("font-size", "40px").attr("alignment-baseline","middle")

   
// Adding  labels in the legend and its style 
svg.append("text").attr("x", 150).attr("y", 70).text("Iris-setosa").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("Iris-versicolor").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("Iris-virginica").style("font-size", "20px").attr("alignment-baseline","middle")
  
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
        	.text("Sepal_Length");
    
    // styling and adding colors to legends
    svg.append("circle").attr("cx",130).attr("cy",70).attr("r", 6).style("fill", "blue")
		svg.append("circle").attr("cx",130).attr("cy",100).attr("r", 6).style("fill", "LightSkyBlue")
		svg.append("circle").attr("cx",130).attr("cy",130).attr("r", 6).style("fill", "red")
   // label x-axis as petal_width
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Petal_Width");
     
     // label y-axis as sepal_length
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  540 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Sepal_Length");
    i++;
  }, 2000);// every 4 seconds change the visualization
};
main();



